==> tecfy_core_package-1.0.5.tar.gz: lib/views/components/home/notification_row.dart <==
part of tecfy_core_client_package;

class NotificationRow extends StatefulWidget {
  final UserNotification notification;
  NotificationRow(this.notification);
  @override
  _NotificationRowState createState() => _NotificationRowState();
}

class _NotificationRowState extends State<NotificationRow> {
  bool actionBusy = false;
  @override
  Widget build(BuildContext context) {
    return Column(
      children: <Widget>[
        ListTile(
          contentPadding: EdgeInsets.only(top: 10.0, bottom: 5.0),
          leading: CircleAvatar(
            radius: 23.0,
            child: widget.notification.userPhotoUrl == null
                ? Icon(Icons.mail)
                : Container(),
            backgroundImage: widget.notification.userPhotoUrl != null
                ? Image.network(widget.notification.userPhotoUrl!).image
                : null,
          ),
          title: new RichText(
            text: new TextSpan(
              // Note: Styles for TextSpans must be explicitly defined.
              // Child text spans will inherit styles from parent
              style: TextStyle(
                fontSize: 14.0,
                color: Colors.black,
              ),
              children: <TextSpan>[
                TextSpan(
                    text: widget.notification.userName,
                    style: TextStyle(fontWeight: FontWeight.bold)),
                TextSpan(text: ' '),
                TextSpan(text: widget.notification.message),
              ],
            ),
          ),
          // title: Row(
          //   children: <Widget>[
          //     Text(widget.notification.name, style: Theme.of(context).textTheme.caption),
          //     SizedBox(width: 10.0),
          //     Text(widget.notification.message, style: Theme.of(context).textTheme.body1, maxLines: 3),
          //   ],
          // ),
          subtitle: actionBusy
              ? Center(
                  child: CircularProgressIndicator(
                      valueColor: AlwaysStoppedAnimation<Color>(
                          ThemeService.mainColor)))
              : widget.notification.isRequest
                  ? Row(
                      // accept and decline buttons
                      children: <Widget>[
                        NotificationButton(
                            label: 'Accept',
                            onPressed: () async {
                              setState(() => actionBusy = true);
                              if (widget.notification.type == 'FriendRequest') {
                                // await FriendService.requestFriendConfirm(widget.notification);
                              }
                              setState(() => actionBusy = false);
                            },
                            main: true),
                        SizedBox(width: 15.0),
                        NotificationButton(
                            label: 'Decline',
                            onPressed: () {
                              // UserNotificationService.markDelete(widget.notification);
                            },
                            main: false),
                      ],
                    )
                  : null,
          trailing: Column(
            crossAxisAlignment: CrossAxisAlignment.end,
            children: <Widget>[
              Text(widget.notification.createdSince,
                  style: Theme.of(context)
                      .textTheme
                      .bodyText1
                      ?.copyWith(fontSize: 10.0)),
              SizedBox(height: 10.0),
              widget.notification.isSeen
                  ? Container(width: 10.0)
                  : CircleAvatar(
                      backgroundColor: ThemeService.mainColor, radius: 5.0)
            ],
          ),
        ),
        Divider(
          height: 0.2,
          indent: 0.1,
        )
      ],
    );
  }
}

==> tecfy_core_package-1.1.19.tar.gz: lib/views/components/home/notification_row.dart <==
part of tecfy_core_client_package;

class NotificationRow extends StatefulWidget {
  final UserNotification notification;
  NotificationRow(this.notification);
  @override
  _NotificationRowState createState() => _NotificationRowState();
}

class _NotificationRowState extends State<NotificationRow> {
  bool _actionBusy = false;
  @override
  Widget build(BuildContext context) {
    return Column(
      children: <Widget>[
        ListTile(
          contentPadding: EdgeInsets.only(top: 10.0, bottom: 5.0),
          leading: CircleAvatar(
            radius: 23.0,
            child: widget.notification.userPhotoUrl == null
                ? Icon(Icons.mail)
                : Container(),
            backgroundImage: widget.notification.userPhotoUrl != null
                ? Image.network(widget.notification.userPhotoUrl!).image
                : null,
          ),
          title: new RichText(
            text: new TextSpan(
              // Note: Styles for TextSpans must be explicitly defined.
              // Child text spans will inherit styles from parent
              style: TextStyle(
                fontSize: 14.0,
                color: Colors.black,
              ),
              children: <TextSpan>[
                TextSpan(
                    text: widget.notification.userName,
                    style: TextStyle(fontWeight: FontWeight.bold)),
                TextSpan(text: ' '),
                TextSpan(text: widget.notification.message),
              ],
            ),
          ),
          // title: Row(
          //   children: <Widget>[
          //     Text(widget.notification.name, style: Theme.of(context).textTheme.caption),
          //     SizedBox(width: 10.0),
          //     Text(widget.notification.message, style: Theme.of(context).textTheme.body1, maxLines: 3),
          //   ],
          // ),
          subtitle: _actionBusy
              ? Center(
                  child: CircularProgressIndicator(
                      valueColor: AlwaysStoppedAnimation<Color>(
                          ThemeService.mainColor)))
              : widget.notification.isRequest
                  ? Row(
                      // accept and decline buttons
                      children: <Widget>[
                        NotificationButton(
                            label: 'Accept',
                            onPressed: () async {
                              setState(() => _actionBusy = true);
                              if (widget.notification.type == 'FriendRequest') {
                                // await FriendService.requestFriendConfirm(widget.notification);
                              }
                              setState(() => _actionBusy = false);
                            },
                            main: true),
                        SizedBox(width: 15.0),
                        NotificationButton(
                            label: 'Decline',
                            onPressed: () {
                              // UserNotificationService.markDelete(widget.notification);
                            },
                            main: false),
                      ],
                    )
                  : null,
          trailing: Column(
            crossAxisAlignment: CrossAxisAlignment.end,
            children: <Widget>[
              Text(widget.notification.createdSince,
                  style: Theme.of(context)
                      .textTheme
                      .bodyText1
                      ?.copyWith(fontSize: 10.0)),
              SizedBox(height: 10.0),
              widget.notification.isSeen
                  ? Container(width: 10.0)
                  : CircleAvatar(
                      backgroundColor: ThemeService.mainColor, radius: 5.0)
            ],
          ),
        ),
        Divider(
          height: 0.2,
          indent: 0.1,
        )
      ],
    );
  }
}
